@@ -138,12 +138,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             }
 
             pub fn start_payment_processing(
-                subscription_name: String,
                 internal_ctx: InternalContext,
                 context_provider: Arc<super::#server_type_name>,
             ) {
                 task::spawn(async move {
-                    let subscription = internal_ctx.pubsub_client.subscribe(subscription_name);
+                    let subscription = internal_ctx.payment_processing_subscription.clone();
                     while subscription.client().is_running() {
                         match subscription.get_messages::<Message>().await {
                             Ok(messages) => {
